==> aws-cdk.triggers-1.149.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_triggers_TriggerInvalidation(p) {
}
function _aws_cdk_triggers_TriggerFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if ("architectures" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#architectures", "use `architecture`");
    if (!visitedObjects.has(p.architectures))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.architectures);
    if (!visitedObjects.has(p.events))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("@aws-cdk/aws-iam/.warnings.jsii.js")._aws_cdk_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_ILayerVersion(p.layers);
    if ("securityGroup" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#securityGroup", "- This property is deprecated, use securityGroups instead");
    if (!visitedObjects.has(p.securityGroups))
        require("@aws-cdk/aws-ec2/.warnings.jsii.js")._aws_cdk_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_triggers_TriggerOptions(p) {
}
function _aws_cdk_triggers_TriggerProps(p) {
}
function _aws_cdk_triggers_ITrigger(p) {
}
function _aws_cdk_triggers_Trigger(p) {
}
function _aws_cdk_triggers_TriggerFunction(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_triggers_TriggerInvalidation, _aws_cdk_triggers_TriggerFunctionProps, _aws_cdk_triggers_TriggerOptions, _aws_cdk_triggers_TriggerProps, _aws_cdk_triggers_ITrigger, _aws_cdk_triggers_Trigger, _aws_cdk_triggers_TriggerFunction };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.triggers-1.150.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_triggers_TriggerInvalidation(p) {
}
function _aws_cdk_triggers_TriggerFunctionProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if ("architectures" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#architectures", "use `architecture`");
    if (!visitedObjects.has(p.architectures))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.architectures);
    if (!visitedObjects.has(p.events))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_IEventSource(p.events);
    if (!visitedObjects.has(p.initialPolicy))
        require("@aws-cdk/aws-iam/.warnings.jsii.js")._aws_cdk_aws_iam_PolicyStatement(p.initialPolicy);
    if (!visitedObjects.has(p.layers))
        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_ILayerVersion(p.layers);
    if ("securityGroup" in p)
        print("@aws-cdk/aws-lambda.FunctionOptions#securityGroup", "- This property is deprecated, use securityGroups instead");
    if (!visitedObjects.has(p.securityGroups))
        require("@aws-cdk/aws-ec2/.warnings.jsii.js")._aws_cdk_aws_ec2_ISecurityGroup(p.securityGroups);
    visitedObjects.delete(p);
}
function _aws_cdk_triggers_TriggerProps(p) {
}
function _aws_cdk_triggers_TriggerOptions(p) {
}
function _aws_cdk_triggers_ITrigger(p) {
}
function _aws_cdk_triggers_Trigger(p) {
}
function _aws_cdk_triggers_TriggerFunction(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_triggers_TriggerInvalidation, _aws_cdk_triggers_TriggerFunctionProps, _aws_cdk_triggers_TriggerProps, _aws_cdk_triggers_TriggerOptions, _aws_cdk_triggers_ITrigger, _aws_cdk_triggers_Trigger, _aws_cdk_triggers_TriggerFunction };
module.exports.DeprecationError = DeprecationError;
